==============
yuzu
==============


.. image:: https://img.shields.io/pypi/v/yuzu.svg
        :target: https://pypi.python.org/pypi/yuzu

.. image:: https://readthedocs.org/projects/yuzu-python/badge/?version=latest
        :target: https://yuzu-python.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Lightweight and useful annotation package for logging and caching


* Free software: MIT license
* Documentation: https://yuzu-python.readthedocs.io.


Features
--------

* TODO

  - write document

Credits
-------
